import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useContext, useState } from 'react';
import { useGetTotalNumberOfTests, useInitWindowObject, useRunTests } from '../lib/hooks';
import { getInitialContainerState, updateTest } from '../lib/testHelpers';
import { updateWindowObject } from '../lib/window';
const TestContext = createContext(undefined);
export const useTestContext = () => {
    const context = useContext(TestContext);
    if (!context) {
        throw new Error('useTestContext must be used within a TestProvider');
    }
    return context;
};
export const TestProvider = ({ beforeAndAfterFunctions, containerId, children }) => {
    const [containerState, setContainerState] = useState(getInitialContainerState(containerId));
    useInitWindowObject(containerId, containerState);
    useGetTotalNumberOfTests(containerId, containerState.totalNumberOfTests, setContainerState);
    const updateTestClosure = (test, updateIndex = true) => {
        return updateTest(test, updateIndex, containerId, containerState, setContainerState);
    };
    useRunTests(containerState, updateTestClosure, beforeAndAfterFunctions);
    const reRunTests = () => {
        setContainerState((prevContainerState) => {
            // TODO: FIXME: These are not deep copies. Maybe use immer or something?
            const newContainerState = { ...prevContainerState };
            newContainerState.reRunCount += 1;
            newContainerState.currentTestIndex = 0;
            newContainerState.tests = {};
            return newContainerState;
        });
    };
    const registerTest = (test) => {
        setContainerState((prevContainerState) => {
            const newContainerState = { ...prevContainerState };
            newContainerState.tests[test.id] = test;
            updateWindowObject(newContainerState, containerId);
            return newContainerState;
        });
    };
    const addGroup = (group) => {
        setContainerState((prevContainerState) => {
            const newContainerState = { ...prevContainerState };
            newContainerState.groupRecord[group.title] = group;
            updateWindowObject(newContainerState, containerId);
            return newContainerState;
        });
    };
    const contextProviderValue = {
        tests: containerState.tests,
        groupRecord: containerState.groupRecord,
        reRunCount: containerState.reRunCount,
        containerId,
        registerTest,
        addGroup,
        reRunTests,
    };
    return (_jsx(TestContext.Provider, { value: contextProviderValue, children: children }));
};
